@@ -55,6 +55,7 @@ CREDITS = dict(
         'Roger VC (Catalan)',
         'Lukáš Linhart (Czech)',
         'Jakub Soukup (Czech)',
+        'Petr Horník (Czech)',
         'Dingzhong Chen (Simplified Chinese)',
         'Eric-Song-Nop (Simplified Chinese)',
         'Inaha (Simplified Chinese)',
@@ -84,8 +85,8 @@ CREDITS = dict(
         'Vortex Acherontic (German)',
         'Dlurak (German)',
         'Mirko P. (German)',
+        'Simon Barth (German)',
         'Scrambled777 (Hindi)',
-        'mondstern (Hungarian)',
         'Milo Ivir (Croatian)',
         'Alifiyan Rosyidi (Indonesian)',
         'Alim Satria (Indonesian)',
@@ -97,9 +98,11 @@ CREDITS = dict(
         'Andrea Scarano (Italian)',
         'pasquale ruotolo (Italian)',
         'Riccardo Luise (Italian)',
+        'cas9 (Italian)',
         'Velyvis (Lithuanian)',
         'Lili Kurek (Polish)',
         'Aleksander Warzyniak (Polish)',
+        'Kurai (Polish)',
         'ssantos (Portuguese)',
         'Ademario Cunha (Portuguese)',
         'SpiralPack 527 (Portuguese)',
@@ -126,6 +129,7 @@ CREDITS = dict(
         'Bezruchenko Simon (Ukrainian)',
         'Максим Горпиніч (Ukrainian)',
         'niyaki hayyashi (Vietnamese)',
+        'Loc Huynh (Vietnamese)',
     ),
     supporters=(
         'gondolyr',
@@ -135,9 +139,15 @@ CREDITS = dict(
 
 RELEASE_NOTES = """
 <ul>
-    <li>[Servers] Added Zenko (UK)</li>
-    <li>[Explorer] Servers: Kavita and Komga join Local in `Other` section</li>
-    <li>[L10n] Updated French, Russian and Ukrainian translations</li>
+    <li>[Card] Added categories in `Info` page</li>
+    <li>[Preferences] Advanced: Improved `Clear WebView Data`</li>
+    <li>[Trackers] Improved MangaUpdates</li>
+    <li>[Servers] Added DocTruyen3Q (VI)</li>
+    <li>[Servers] Comix (EN): Update</li>
+    <li>[Servers] EZmanga (EN): Update</li>
+    <li>[Servers] MangaCrab (ES): Update</li>
+    <li>[Servers] Mangas Top (pt_BR): Update</li>
+    <li>[L10n] Updated Croatian, Russian and Vietnamese translations</li>
 </ul>
 <p>Happy reading.</p>
 """
