@@ -67,7 +67,7 @@ class HistoryDateChapterRow(Adw.ActionRow):
 
         self.set_title(html_escape(chapter.manga.name))
         self.set_title_lines(1)
-        self.set_subtitle(chapter.title)
+        self.set_subtitle(html_escape(chapter.title))
         self.set_subtitle_lines(1)
 
         # Cover
@@ -198,12 +198,11 @@ class HistoryPage(Adw.NavigationPage):
             ORDER BY last_read DESC
         """
         records = db_conn.execute(query, (start,)).fetchall()
-        db_conn.close()
 
         if records:
             dates = {}
             for record in records:
-                chapter = Chapter.get(record['id'])
+                chapter = Chapter.get(record['id'], db_conn=db_conn)
                 date = record['last_read_date']  # ISO 8601 date string
                 if date not in dates:
                     dates[date] = []
@@ -218,6 +217,8 @@ class HistoryPage(Adw.NavigationPage):
         else:
             self.stack.set_visible_child_name('empty')
 
+        db_conn.close()
+
     def search(self, _entry):
         for date_box in self.dates_box:
             listbox = date_box.get_last_child()
