@@ -7,9 +7,12 @@ from komikku.servers.multi.paprika import Paprika
 
 class Mangareadercc(Paprika):
     id = 'mangareadercc'
-    name = 'Manga Reader (cc)'
+    name = 'MangaReader (cc)'
     lang = 'en'
+
+    has_cf = True
     is_nsfw = True
 
-    base_url = 'https://www.mangareader.cc'
-    logo_url = base_url + '/frontend/imgs/favicon16.png'
+    base_url = 'https://mangareader.in'
+    logo_url = base_url + '/frontend/imgs/favico.png'
+    bypass_cf_url = base_url + '/manga/selena'
