@@ -2,12 +2,13 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
-from bs4 import BeautifulSoup
 import datetime
+
+from bs4 import BeautifulSoup
 import requests
 
+from komikku.consts import USER_AGENT
 from komikku.servers import Server
-from komikku.servers import USER_AGENT
 from komikku.servers.utils import convert_date_string
 from komikku.utils import get_buffer_mime_type
 
@@ -19,6 +20,7 @@ class Monkeyuser(Server):
     true_search = False
 
     base_url = 'https://www.monkeyuser.com'
+    donate_url = base_url
     logo_url = base_url + '/images/logo.png'
     chapter_url = base_url + '{0}'
     image_url = base_url + '{0}'
