@@ -9,6 +9,7 @@ import importlib
 import inspect
 from io import BytesIO
 import itertools
+import json
 import logging
 import math
 from operator import itemgetter
@@ -174,7 +175,11 @@ def do_login(func):
         if not server.logged_in:
             server.do_login()
 
-        return func(*args, **kwargs)
+        if server.logged_in:
+            return func(*args, **kwargs)
+
+        logger.warning('Server %s is not logged in. Please check credential in Settings', server.name)
+        return None
 
     return wrapper
 
@@ -190,10 +195,16 @@ def get_allowed_servers_list(settings):
 
         server_settings = servers_settings.get(get_server_main_id_by_id(server_data['id']))
         if server_settings is not None:
-            if (not server_settings['enabled']
-                    or (len(servers_languages) > 1 and server_settings['langs'].get(server_data['lang']) is False)):
-                # Server is disabled or several languages are selected and server language is disabled
+            if not server_settings.get('enabled', True):
+                # Server is disabled
                 continue
+            if len(servers_languages) > 0:
+                if server_data['lang'] and server_data['lang'] not in servers_languages:
+                    # Server language is not in list of enabled server languages
+                    continue
+                if not server_settings.get('langs', {}).get(server_data['lang'], True):
+                    # Server is disabled for this language
+                    continue
 
         if settings.nsfw_content is False and server_data['is_nsfw']:
             continue
@@ -266,13 +277,16 @@ def get_servers_list(include_disabled=False, order_by=('lang', 'name')):
                 servers.append(dict(
                     id=obj.id,
                     name=obj.name,
+                    description=obj.description,
                     lang=obj.lang,
+                    base_url=obj.base_url,
                     has_login=obj.has_login,
                     is_nsfw=obj.is_nsfw,
                     is_nsfw_only=obj.is_nsfw_only,
                     logo_path=logo_path if os.path.exists(logo_path) else None,
                     logo_url=obj.logo_url,
                     module=module,
+                    params=obj.params,
                     class_name=get_server_class_name_by_id(obj.id),
                 ))
 
@@ -369,7 +383,7 @@ def get_session_cookies(s):
     return s.cookies.jar if hasattr(s.cookies, 'jar') else s.cookies
 
 
-def get_soup_element_inner_text(tag, text=None, recursive=True):
+def get_soup_element_inner_text(tag, text=None, sep=' ', recursive=True):
     """
     Returns inner text of a tag
 
@@ -394,7 +408,41 @@ def get_soup_element_inner_text(tag, text=None, recursive=True):
         elif recursive:
             get_soup_element_inner_text(el, text)
 
-    return ' '.join(text).strip()
+    return sep.join(text).strip()
+
+
+def parse_nextjs_hydration(soup, keyword):
+    """
+    Goes through all scripts in `soup`
+
+    If a Next.js hydration containing `keyword` is found, it's deserialized and returned
+    """
+
+    info = None
+
+    for script_element in soup.select('script'):
+        script = script_element.string
+        if not script or not script.startswith('self.__next_f.push([1,') or keyword not in script:
+            continue
+
+        line = script.strip().replace('self.__next_f.push([1,', '')
+
+        start = 0
+        for c in line:
+            if c in ('{', '['):
+                break
+            start += 1
+
+        line = line[start:-3]
+
+        try:
+            info = json.loads(json.loads(f'"{line}"'))
+        except Exception as e:
+            logger.debug(f'ERROR: {line}')
+            logger.debug(e)
+        break
+
+    return info
 
 
 def sojson4_decode(s):
